#ifndef __MDFN_PSX_INPUT_JUSTIFIER_H
#define __MDFN_PSX_INPUT_JUSTIFIER_H

namespace MDFN_IEN_PSX
{

InputDevice *Device_Justifier_Create(void);
extern IDIISG Device_Justifier_IDII;

}
#endif
